@@ -30,6 +30,7 @@
 #include <libudev.h>
 
 #include "cpacfstats.h"
+#include "lib/libcpumf.h"
 #include "../include/lib/zt_common.h"
 
 /* correlation between counter and perf counter string */
@@ -123,16 +124,6 @@ static struct percpucounter *findcpu(unsigned int cpunum, int unlinkflag)
 	return NULL;
 }
 
-static long perf_event_open(struct perf_event_attr *hw_event, pid_t pid,
-			    int cpu, int group_fd, unsigned long flags)
-{
-	int ret;
-
-	ret = syscall(__NR_perf_event_open, hw_event, pid, cpu,
-		group_fd, flags);
-	return ret;
-}
-
 static int perf_supported(void)
 {
 	return !access("/proc/sys/kernel/perf_event_paranoid", R_OK);
@@ -150,6 +141,10 @@ static int perf_counter_supported(const char *pmu, const char *counter)
 	return !access(buf, R_OK);
 }
 
+/**
+ * Returns 1 if counters are authorized, -1 if counters are unauthorized,
+ * and 0 otherwise which indicates that the counters are unsupported
+ */
 static int cpumf_authorized(void)
 {
 	unsigned vermin, vermax, auth;
@@ -168,10 +163,12 @@ static int cpumf_authorized(void)
 		if (sscanf(line,
 			   "CPU-MF: Counter facility: version=%d.%d authorization=%x",
 			   &vermin, &vermax, &auth) == 3) {
-			if (auth & 0x8)
+			if (auth & 0x8) {
 				res = 1;
-			else
+			} else {
 				eprint("CPU-MF counters not authorized.\n");
+				res = -1;
+			}
 			found = 1;
 			break;
 		}
@@ -242,7 +239,7 @@ static int activatecpu(unsigned int cpu, unsigned int *supported_counters)
 	}
 	/* activate CPU-MF */
 	for (i = 0; i < ALL_COUNTER; ++i) {
-		if (ctr_state[i] == UNSUPPORTED)
+		if (ctr_state[i] == UNSUPPORTED || ctr_state[i] == UNAUTHORIZED)
 			continue;
 		memset(&pfm_event, 0, sizeof(pfm_event));
 		pfm_event.size = sizeof(pfm_event);
@@ -407,7 +404,7 @@ static int perf_load_counter_data(void)
 	int i, res = 0;
 
 	for (i = 0; i < ALL_COUNTER; ++i) {
-		if (ctr_state[i] != UNSUPPORTED)
+		if (ctr_state[i] != UNSUPPORTED && ctr_state[i] != UNAUTHORIZED)
 			res |= perf_event_encode(&pmf_counter_data[i].pmutype,
 						 &pmf_counter_data[i].eventid,
 						 pmf_counter_name[i].pmu,
@@ -483,6 +480,7 @@ int perf_init(unsigned int *supported_counters)
 	};
 	unsigned long maxfd;
 	struct rlimit rlim;
+	int cpumf_state;
 	int i, num;
 	FILE *f;
 
@@ -496,10 +494,15 @@ int perf_init(unsigned int *supported_counters)
 	 * counters for PAI. */
 	num = ALL_COUNTER + 2;
 
-	if (!cpumf_authorized()) {
+	cpumf_state = cpumf_authorized();
+	if (cpumf_state == 0) {
 		for (i = 0; i < ALL_COUNTER; ++i)
 			ctr_state[i] = UNSUPPORTED;
 		num -= ALL_COUNTER;
+	} else if (cpumf_state == -1) {
+		for (i = 0; i < ALL_COUNTER; ++i)
+			ctr_state[i] = UNAUTHORIZED;
+		num -= ALL_COUNTER;
 	} else {
 		for (i = 0; i < ALL_COUNTER; i++) {
 			if (!perf_counter_supported("cpum_cf", cpum_cf[i])) {
