@@ -35,69 +35,7 @@
 #include "lib/util_str.h"
 #include "lib/libcpumf.h"
 
-#define STR_SUB(x) #x
-#define STR(x)	   STR_SUB(x)
-
-#define OPT_FORMAT		256	/* --format XXX option */
-#define DEFAULT_LOOP_INTERVAL	60	/* loop interval in seconds */
-
-static struct util_opt opt_vec[] = {
-	UTIL_OPT_SECTION("OPTIONS"),
-	{
-		.option = { "all", no_argument, NULL, 'a' },
-		.desc = "Displays all CPUs in output"
-	},
-	{
-		.option = { "delta", no_argument, NULL, 'd' },
-		.desc = "Display delta counter values"
-	},
-	{
-		.option = { "counters", required_argument, NULL, 'c' },
-		.argument = "LIST",
-		.desc = "Specify comma separated list of counters to display"
-	},
-	{
-		.option = { "format", required_argument, NULL, OPT_FORMAT },
-		.argument = "FORMAT",
-		.flags = UTIL_OPT_FLAG_NOSHORT,
-		.desc = "List counters in specified FORMAT (" FMT_TYPE_NAMES ")"
-	},
-	{
-		.option = { "loops", required_argument, NULL, 'l' },
-		.argument = "COUNT",
-		.desc = "Number of read operations"
-	},
-	{
-		.option = { "interval", required_argument, NULL, 'i' },
-		.argument = "SECONDS",
-		.desc = "Time to wait between loop iterations (default "
-			STR(DEFAULT_LOOP_INTERVAL) "s)"
-	},
-	{
-		.option = { "numeric", no_argument, NULL, 'n' },
-		.desc = "Sort PAI counters by counter number"
-	},
-	{
-		.option = { "short", no_argument, NULL, 's' },
-		.desc = "Abbreviate counter name with counter set letter and number"
-	},
-	{
-		.option = { "type", required_argument, NULL, 't' },
-		.argument = "TYPE",
-		.desc = "Type of PAI counters to show: crypto, nnpa"
-	},
-	{
-		.option = { "hex0x", no_argument, NULL, 'X' },
-		.desc = "Counter values in hexadecimal format with leading 0x"
-	},
-	{
-		.option = { "hex", no_argument, NULL, 'x' },
-		.desc = "Counter values in hexadecimal format"
-	},
-	UTIL_OPT_HELP,
-	UTIL_OPT_VERSION,
-	UTIL_OPT_END
-};
+#include "lspai_cli.h"
 
 static const struct util_prg prg = {
 	.desc = "List Processor Assist Information counter sets",
@@ -727,7 +665,7 @@ int main(int argc, char **argv)
 
 	util_list_init(&pai_list, struct pai_node, node);
 	util_prg_init(&prg);
-	util_opt_init(opt_vec, NULL);
+	util_opt_init(lspai_opt_vec, NULL);
 
 	while ((ch = util_opt_getopt_long(argc, argv)) != -1) {
 		switch (ch) {
