@@ -12,19 +12,26 @@
 
 #include <ctype.h>
 #include <sys/sysmacros.h>
+#include <sys/ioctl.h>
 
 #include "lib/util_libc.h"
+#include "lib/util_proc.h"
+#include "lib/util_base.h"
 #include "lib/zt_common.h"
+#include "lib/util_path.h"
 
 #include "ipl_tools.h"
 #include "proc.h"
+#include <linux/raid/md_u.h>
 
 #define BOOTPARMS_NSS_MAX	56
 #define BOOTPARMS_CCW_MAX	64
-#define BOOTPARMS_FCP_MAX	3452
+#define BOOTPARMS_SCPDATA_MAX	3452
 
 #define OPT_BRCHR		0x80
 
+#define MD_MAJOR		9
+
 enum target_type {
 	TT_CCW,
 	TT_FCP,
@@ -414,15 +421,38 @@ static int set_reipl_type(const char *dev_name)
 	return 0;
 }
 
-static int get_chreipl_helper_cmd(dev_t dev, char cmd[PATH_MAX])
+static int is_md_device(const char *dev_name)
+{
+	char abs_dev_name[PATH_MAX];
+	mdu_array_info_t array;
+	int is_md_device = 0;
+	int fd;
+
+	if (snprintf(abs_dev_name, PATH_MAX, "/dev/%s", dev_name) >= PATH_MAX)
+		return 0;
+	fd = open(abs_dev_name, O_RDONLY);
+	if (fd == -1)
+		return 0;
+	if (ioctl(fd, GET_ARRAY_INFO, &array) >= 0)
+		is_md_device = 1;
+	close(fd);
+	return is_md_device;
+}
+
+static int get_chreipl_helper_cmd(dev_t dev, char *dev_name, char cmd[PATH_MAX])
 {
-	char *chreipl_helper;
 	struct proc_dev_entry pde;
+	char *chreipl_helper;
+	char *driver_name;
 
 	if (proc_dev_get_entry(dev, 1, &pde) != 0)
 		return -1;
+	driver_name = pde.name;
+	if (strcmp(driver_name, UTIL_PROC_DEV_ENTRY_BLKEXT) == 0 &&
+	    is_md_device(dev_name))
+		driver_name = UTIL_PROC_DEV_ENTRY_MD;
 	util_asprintf(&chreipl_helper,
-		      "%s/%s.%s", TOOLS_LIBDIR, "chreipl_helper", pde.name);
+		      "%s.%s", util_libdir_path("chreipl_helper"), driver_name);
 	if (access(chreipl_helper, X_OK) != 0) {
 		proc_dev_free_entry(&pde);
 		free(chreipl_helper);
@@ -437,7 +467,7 @@ static int get_chreipl_helper_cmd(dev_t dev, char cmd[PATH_MAX])
 /*
  * Use chreipl_helper (E.g. for device mapper devices)
  */
-static int set_reipl_type_helper(int maj, int min)
+static int set_reipl_type_helper(int maj, int min, char *dev_name)
 {
 	char helper_cmd[PATH_MAX], buf[4096];
 	struct proc_part_entry ppe;
@@ -445,7 +475,7 @@ static int set_reipl_type_helper(int maj, int min)
 	dev_t dev;
 	FILE *fh;
 
-	if (get_chreipl_helper_cmd(makedev(maj, min), helper_cmd) != 0)
+	if (get_chreipl_helper_cmd(makedev(maj, min), dev_name, helper_cmd) != 0)
 		return -1;
 	fh = popen(helper_cmd, "r");
 	if (fh == NULL)
@@ -499,7 +529,7 @@ static void parse_node_args(char *nargv[], int nargc)
 		ERR_EXIT("Invalid device node \"%s\" specified", path);
 	if (set_reipl_type(ppe.name) == 0)
 		goto out;
-	if (set_reipl_type_helper(major(dev), minor(dev)) == 0)
+	if (set_reipl_type_helper(major(dev), minor(dev), ppe.name) == 0)
 		goto out;
 	ERR_EXIT("Unsupported device node \"%s\" specified", path);
 out:
@@ -719,11 +749,12 @@ static void parse_chreipl_options(int argc, char *argv[])
 
 static void check_exists(const char *path, const char *attr)
 {
-	char fpath[PATH_MAX];
+	char *fpath;
 
-	snprintf(fpath, sizeof(fpath), "/sys/firmware/%s", path);
+	fpath = util_path_sysfs("firmware/%s", path);
 	if (access(fpath, F_OK) != 0)
 		ERR_EXIT("System does not allow one to set %s", attr);
+	free(fpath);
 }
 
 static void write_str_optional(char *string, char *file, int exit_on_fail,
@@ -739,7 +770,7 @@ static void write_str_optional(char *string, char *file, int exit_on_fail,
  * IMPLEMENTATION:
  *
  * "cio_ignore --is-ignored <busid>" returns 0 if the device is ignored,
- * 1 for internal errrors, and 2 if the device is not ignored.
+ * 1 for internal errors, and 2 if the device is not ignored.
  *
  * We get the "cio_ignore" exit status by the return code of the system()
  * function via WEXITSTATUS().
@@ -804,6 +835,12 @@ static void chreipl_eckd(void)
 		ERR_EXIT("Could not find DASD ECKD device \"%s\"", l.busid);
 	}
 
+	check_exists("reipl/eckd/device", "\"eckd\" re-IPL target");
+	if (l.bootparms_set && strlen(l.bootparms) > BOOTPARMS_SCPDATA_MAX) {
+		ERR_EXIT("Maximum boot parameter length exceeded (%zu/%u)",
+			 strlen(l.bootparms), BOOTPARMS_SCPDATA_MAX);
+	}
+
 	if (l.reipl_clear >= 0) {
 		check_exists("reipl/eckd/clear", "ECKD re-IPL clear attribute");
 		write_str(l.reipl_clear ? "1" : "0", "reipl/eckd/clear");
@@ -817,6 +854,8 @@ static void chreipl_eckd(void)
 	write_str(l.bootprog, "reipl/eckd/bootprog");
 	write_str(l.busid, "reipl/eckd/device");
 	write_str_optional(l.loadparm, "reipl/eckd/loadparm", l.loadparm_set, "loadparm");
+	write_str_optional(l.bootparms, "reipl/eckd/scp_data", l.bootparms_set,
+			   "boot parameters");
 	write_str("eckd", "reipl/reipl_type");
 	print_eckd(0, "eckd");
 }
@@ -831,9 +870,9 @@ static void chreipl_fcp(void)
 		ERR_EXIT("Could not find FCP device \"%s\"", l.busid);
 	}
 	check_exists("reipl/fcp/device", "\"fcp\" re-IPL target");
-	if (l.bootparms_set && strlen(l.bootparms) > BOOTPARMS_FCP_MAX) {
+	if (l.bootparms_set && strlen(l.bootparms) > BOOTPARMS_SCPDATA_MAX) {
 		ERR_EXIT("Maximum boot parameter length exceeded (%zu/%u)",
-			 strlen(l.bootparms), BOOTPARMS_FCP_MAX);
+			 strlen(l.bootparms), BOOTPARMS_SCPDATA_MAX);
 	}
 
 	if (l.reipl_clear >= 0) {
@@ -874,9 +913,9 @@ static void chreipl_nvme(void)
 	}
 	check_exists("reipl/nvme/fid", "\"nvme\" re-IPL target");
 
-	if (l.bootparms_set && strlen(l.bootparms) > BOOTPARMS_FCP_MAX) {
+	if (l.bootparms_set && strlen(l.bootparms) > BOOTPARMS_SCPDATA_MAX) {
 		ERR_EXIT("Maximum boot parameter length exceeded (%zu/%u)",
-			 strlen(l.bootparms), BOOTPARMS_FCP_MAX);
+			 strlen(l.bootparms), BOOTPARMS_SCPDATA_MAX);
 	}
 
 	if (l.reipl_clear >= 0) {
@@ -920,13 +959,14 @@ static void chreipl_nss(void)
 
 static void chreipl_node(void)
 {
-	char path[PATH_MAX];
+	char *path;
 
 	if (!l.dev_set)
 		ERR_EXIT("No device node specified");
-	snprintf(path, sizeof(path), "/sys/block/%s/device", l.dev);
+	path = util_path_sysfs("block/%s/device", l.dev);
 	if (chdir(path) != 0)
 		ERR_EXIT("Could not find device \"%s\"", l.dev);
+	free(path);
 
 	switch (l.reipl_type) {
 	case REIPL_CCW:
