@@ -9,7 +9,6 @@
  * it under the terms of the MIT license. See LICENSE for details.
  */
 
-#include <argz.h>
 #include <libgen.h>
 #include <stdbool.h>
 #include <stdio.h>
@@ -39,8 +38,6 @@ static struct util_opt_l {
 	const char *command;
 } l;
 
-struct util_opt_l *util_opt_l = &l;
-
 /// @endcond
 
 #define util_opt_iterate(opt) \
