@@ -2,7 +2,7 @@
 //
 // Copyright IBM Corp. 2023
 
-use super::user_data::UserData;
+use super::{guest_secret::ListableSecretHdr, user_data::UserData};
 use crate::{
     assert_size,
     crypto::{hkdf_rfc_5869, AeadEncryptionResult},
@@ -17,12 +17,12 @@ use openssl::{
     md::Md,
     pkey::{PKey, Private, Public},
 };
-use pv_core::{request::RequestVersion, secret::AddSecretMagic};
-use zerocopy::AsBytes;
+use pv_core::{request::RequestVersion, secret::AddSecretMagic, uv::SecretId};
+use zerocopy::{Immutable, IntoBytes};
 
 /// Authenticated data w/o user data
 #[repr(C)]
-#[derive(Debug, Clone, Copy, AsBytes)]
+#[derive(Debug, Clone, Copy, IntoBytes, Immutable)]
 struct ReqAuthData {
     flags: UvFlags,
     boot_tags: BootHdrTags,
@@ -283,6 +283,13 @@ impl AddSecretRequest {
             .map(|res| res.into_buf())
     }
 
+    /// Get a copy of the secret ID if any
+    pub fn bin_id(asrcb: &[u8]) -> Result<Option<SecretId>> {
+        AddSecretMagic::try_from_bytes(asrcb)?;
+        BinReqValues::get(asrcb)
+            .map(|req| req.req_dep_aad::<ListableSecretHdr>().map(|a| a.id.clone()))
+    }
+
     /// Get a copy of the add secret request tag
     pub fn bin_tag(asrcb: &[u8]) -> Result<Vec<u8>> {
         AddSecretMagic::try_from_bytes(asrcb)?;
