@@ -2,6 +2,7 @@
 //
 // Copyright IBM Corp. 2023, 2024
 #![doc = include_str!("../README.md")]
+mod apdevice;
 mod confidential;
 mod error;
 mod macros;
@@ -20,9 +21,11 @@ pub mod attest {
 /// Miscellaneous functions and definitions
 pub mod misc {
     pub use crate::utils::pv_guest_bit_set;
-    pub use crate::utils::{create_file, open_file, read_exact_file, read_file, write_file};
-    pub use crate::utils::{decode_hex, parse_hex, to_u16, to_u32, try_parse_u128, try_parse_u64};
+    pub use crate::utils::{create_file, open_file};
+    pub use crate::utils::{decode_hex, encode_hex, parse_hex};
     pub use crate::utils::{read, write};
+    pub use crate::utils::{read_exact_file, read_file, read_file_string, write_file};
+    pub use crate::utils::{to_u16, to_u32, try_parse_u128, try_parse_u64};
     pub use crate::utils::{Flags, Lsb0Flags64, Msb0Flags64};
 }
 
@@ -70,5 +73,29 @@ pub mod secret {
     pub use crate::uvsecret::UserDataType;
 }
 
+/// Functionalities for the AP bus
+pub mod ap {
+    pub use crate::apdevice::Apqn;
+    pub use crate::apdevice::RE_QUEUE_DIR;
+    pub use crate::apdevice::{get_apqn_bind_state, set_apqn_bind_state};
+    /// AP modes
+    pub mod apqn_mode {
+        pub use crate::apdevice::ApqnMode::{self, *};
+    }
+    /// AP info for each state
+    pub mod apqn_info {
+        pub use crate::apdevice::ApqnInfo::{self, *};
+        pub use crate::apdevice::{ApqnInfoAccel, ApqnInfoCca, ApqnInfoEp11};
+    }
+    /// AP bind states
+    pub mod bind_state {
+        pub use crate::apdevice::BindState::{self, *};
+    }
+    /// AP association states
+    pub mod assoc_state {
+        pub use crate::apdevice::AssocState::{self, *};
+    }
+}
+
 // Internal definitions/ imports
 const PAGESIZE: usize = 0x1000;
