@@ -2,9 +2,15 @@
 //
 // Copyright IBM Corp. 2024
 
-use std::{env, fmt::Display, path::PathBuf};
+use std::fmt::Display;
+use std::str::FromStr;
+use std::string::ToString;
+use std::{env, ffi::OsStr, io::IsTerminal, path::PathBuf};
 
-use clap::{ArgGroup, Args, Command, CommandFactory, Parser, ValueEnum, ValueHint};
+use clap::{
+    builder::{PossibleValue, TypedValueParser},
+    Arg, ArgGroup, Args, Command, CommandFactory, Parser, ValueEnum, ValueHint,
+};
 use log::warn;
 use utils::{CertificateOptions, DeprecatedVerbosityOptions};
 
@@ -206,21 +212,137 @@ pub struct CreateBootImageLegacyFlags {
 }
 
 #[non_exhaustive]
-#[derive(Clone, PartialEq, Eq, PartialOrd, Ord, ValueEnum, Debug)]
-pub enum OutputFormat {
+#[derive(Clone, Copy, PartialEq, Eq, PartialOrd, Ord, ValueEnum, Debug)]
+pub enum OutputFormatKind {
+    /// Human-readable, unstable text format
+    Text,
     /// JSON format.
     Json,
 }
 
-impl Display for OutputFormat {
+impl Display for OutputFormatKind {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        write!(
-            f,
-            "{}",
-            match self {
-                Self::Json => "JSON",
+        match self {
+            Self::Text => write!(f, "human-readable"),
+            Self::Json => write!(f, "JSON"),
+        }
+    }
+}
+
+impl FromStr for OutputFormatKind {
+    type Err = String;
+
+    fn from_str(s: &str) -> Result<Self, Self::Err> {
+        match s {
+            "text" => Ok(Self::Text),
+            "json" => Ok(Self::Json),
+            _ => Err(format!("Invalid output format: {s}")),
+        }
+    }
+}
+
+#[derive(Debug, Clone, Copy, PartialEq, Eq)]
+pub enum OutputFormatVariant {
+    /// Default
+    Default,
+    /// Full
+    Full,
+    /// Minified
+    Minify,
+    /// Pretty
+    Pretty,
+}
+
+#[derive(Debug, Clone, Copy, PartialEq, Eq)]
+pub struct OutputFormatSpec {
+    pub kind: OutputFormatKind,
+    pub variant: OutputFormatVariant,
+}
+
+impl OutputFormatSpec {
+    pub fn detect() -> Self {
+        let kind = if std::io::stdout().is_terminal() {
+            OutputFormatKind::Text
+        } else {
+            OutputFormatKind::Json
+        };
+        Self {
+            kind,
+            variant: OutputFormatVariant::Default,
+        }
+    }
+}
+
+#[derive(Clone, Default)]
+struct OutputFormatSpecParser;
+
+impl TypedValueParser for OutputFormatSpecParser {
+    type Value = OutputFormatSpec;
+
+    fn parse_ref(
+        &self,
+        cmd: &Command,
+        arg: Option<&Arg>,
+        value: &OsStr,
+    ) -> Result<Self::Value, clap::error::Error> {
+        let s = value.to_string_lossy();
+        let mut parts = s.splitn(2, ':');
+        let arg_name = arg.unwrap().get_id().to_string();
+        let kind_s = parts.next().unwrap().to_ascii_lowercase();
+        let variant_s = parts.next().map(|x| x.to_ascii_lowercase());
+        let kind = kind_s.as_str().parse().map_err(|_| {
+            let mut err =
+                clap::error::Error::new(clap::error::ErrorKind::ValueValidation).with_cmd(cmd);
+            err.insert(
+                clap::error::ContextKind::InvalidArg,
+                clap::error::ContextValue::String(arg_name.clone()),
+            );
+            err.insert(
+                clap::error::ContextKind::InvalidValue,
+                clap::error::ContextValue::String(kind_s.to_string()),
+            );
+            err
+        })?;
+
+        let variant = match (kind, variant_s.as_deref()) {
+            (_, None) => OutputFormatVariant::Default,
+            (_, Some("default")) => OutputFormatVariant::Default,
+
+            (OutputFormatKind::Text, Some("full")) => OutputFormatVariant::Full,
+            (OutputFormatKind::Json, Some("pretty")) => OutputFormatVariant::Pretty,
+            (OutputFormatKind::Json, Some("minify")) => OutputFormatVariant::Minify,
+            (_, Some(other)) => {
+                let mut err =
+                    clap::error::Error::new(clap::error::ErrorKind::ValueValidation).with_cmd(cmd);
+                err.insert(
+                    clap::error::ContextKind::InvalidArg,
+                    clap::error::ContextValue::String(arg_name.clone()),
+                );
+                err.insert(
+                    clap::error::ContextKind::InvalidValue,
+                    clap::error::ContextValue::String(format!("{kind_s}:{other}")),
+                );
+                Err(err)?
             }
-        )
+        };
+
+        Ok(OutputFormatSpec { kind, variant })
+    }
+
+    // This is used for shell completion suggestions for `--format`
+    fn possible_values(&self) -> Option<Box<dyn Iterator<Item = PossibleValue> + '_>> {
+        use clap::builder::PossibleValue as PV;
+
+        let vals: Vec<PV> = vec![
+            PV::new("text")
+                .help("Human-readable, unstable text format (default if a terminal is available)"),
+            PV::new("text:full").help("Human-readable, full detail text format"),
+            PV::new("json")
+                .help("Pretty-printed machine-readable JSON (default if no terminal available)"),
+            PV::new("json:pretty").help("Pretty-printed machine-readable JSON"),
+            PV::new("json:minify").help("Minified machine-readable JSON"),
+        ];
+        Some(Box::new(vals.into_iter()))
     }
 }
 
@@ -232,20 +354,58 @@ pub struct SeImgInputArgs {
 }
 
 #[derive(Args, Debug)]
+#[command(group(ArgGroup::new("info-mode").required(true).args(["path", "print_schema"])))]
 pub struct InfoArgs {
     #[clap(flatten)]
-    pub input: SeImgInputArgs,
+    pub input: Option<SeImgInputArgs>,
 
-    /// The output format
-    #[arg(long, value_enum)]
-    pub format: OutputFormat,
-
-    /// Use the key in FILE to decrypt the Secure Execution header.
+    /// Output format for the Secure Execution image information.
     ///
-    /// It is the key that was specified with the command line option
-    /// '--hdr-key' at the Secure Execution image creation.
-    #[arg(long, value_name = "FILE", value_hint = ValueHint::FilePath, alias = "key")]
+    /// If not specified, the format is automatically determined based on
+    /// whether stdout is connected to a terminal.
+    #[arg(long, value_parser=OutputFormatSpecParser::default(), conflicts_with = "print_schema")]
+    pub format: Option<OutputFormatSpec>,
+
+    /// Use the key in FILE to verify the Secure Execution header and optionally
+    /// use '--show-secrets' to decrypt it.
+    ///
+    /// The key must be the same key that was specified with '--hdr-key' when the
+    /// Secure Execution image was created. The key is used to:
+    ///   1. Verify the integrity and authenticity of the header
+    ///   2. Optionally decrypt secrets with '--show-secrets'
+    ///
+    /// Without this option, the information is displayed, but NOT verified, and
+    /// a warning is printed. The displayed data should not be trusted without
+    /// verification.
+    #[arg(long, value_name = "FILE", value_hint = ValueHint::FilePath, alias = "key", verbatim_doc_comment, conflicts_with = "print_schema")]
     pub hdr_key: Option<PathBuf>,
+
+    /// This option reveals sensitive information that is normally encrypted in
+    /// the header, such as:
+    ///   - Customer communication key (CCK)
+    ///   - Image encryption key
+    ///   - Other confidential data
+    ///
+    /// SECURITY WARNING: Only use this option in secure, trusted environments.
+    /// The decrypted secrets should never be exposed in untrusted systems.
+    ///
+    /// This option requires '--hdr-key' to decrypt the header.
+    #[arg(
+        long,
+        requires = "hdr_key",
+        verbatim_doc_comment,
+        conflicts_with = "print_schema"
+    )]
+    pub show_secrets: bool,
+
+    /// Print the schema for the 'info' subcommand and exit.
+    ///
+    /// This outputs the schema that describes the structure of the given output FORMAT
+    /// produced by the 'info' subcommand. The schema can be used for:
+    ///   - Validating output
+    ///   - Building tools that parse the output
+    #[arg(value_name = "FORMAT", long, verbatim_doc_comment)]
+    pub print_schema: Option<OutputFormatKind>,
 }
 
 #[derive(Args, Debug)]
@@ -427,8 +587,17 @@ pub enum SubCommands {
 
     /// Print information about the IBM Secure Execution image.
     ///
-    /// Note that the API and output format is experimental and subject to
-    /// change.
+    /// The 'info' subcommand extracts and displays information about an
+    /// existing IBM Secure Execution image, including information from the
+    /// Secure Execution header. By default, the header is displayed without
+    /// verifying its integrity and authenticity. Use '--hdr-key' to
+    /// authenticate and verify the header integrity.
+    ///
+    /// Output can be formatted as human-readable text or JSON. Use '--format'
+    /// to control the output format and level of detail.
+    ///
+    /// SECURITY NOTE: Without '--hdr-key', the displayed information is NOT
+    /// verified and should not be trusted.
     Info(InfoArgs),
 
     /// Test different aspects of an existing IBM Secure Execution image.
@@ -763,6 +932,11 @@ mod test {
     fn pvimg_info_cli() {
         let args = BTreeMap::new();
         let valid_test_args = [
+            // Format argument is optional
+            flat_map_collect(insert(
+                args.clone(),
+                vec![CliOption::new("image", ["/dev/null"])],
+            )),
             flat_map_collect(insert(
                 args.clone(),
                 vec![
@@ -793,6 +967,30 @@ mod test {
                     CliOption::new("image", ["/dev/null"]),
                 ],
             )),
+            flat_map_collect(insert(
+                args.clone(),
+                vec![
+                    CliOption::new("hdr-key", ["--key", "/dev/null"]),
+                    CliOption::new("format", ["--format=json:default"]),
+                    CliOption::new("image", ["/dev/null"]),
+                ],
+            )),
+            flat_map_collect(insert(
+                args.clone(),
+                vec![
+                    CliOption::new("hdr-key", ["--key", "/dev/null"]),
+                    CliOption::new("format", ["--format=json:minify"]),
+                    CliOption::new("image", ["/dev/null"]),
+                ],
+            )),
+            flat_map_collect(insert(
+                args.clone(),
+                vec![
+                    CliOption::new("hdr-key", ["--key", "/dev/null"]),
+                    CliOption::new("format", ["--format=json:pretty"]),
+                    CliOption::new("image", ["/dev/null"]),
+                ],
+            )),
             // separation between keyword and positional args works
             flat_map_collect(insert(
                 args.clone(),
@@ -810,23 +1008,57 @@ mod test {
                     CliOption::new("verbose", ["-VVV"]),
                 ],
             )),
+            // --print-schema json works standalone
+            flat_map_collect(insert(
+                args.clone(),
+                vec![CliOption::new(
+                    "print-json-schema",
+                    ["--print-schema", "json"],
+                )],
+            )),
         ];
 
         let invalid_test_args = [
-            // the argument '--key-hashes[=<FILE>]' cannot be used with '--host-key-document
-            // <FILE>'
-            flat_map_collect(insert(
-                args.clone(),
-                vec![CliOption::new("image", ["/dev/null"])],
-            )),
             // No default defined for --format
             flat_map_collect(insert(
-                args,
+                args.clone(),
                 vec![
                     CliOption::new("format", ["--format"]),
                     CliOption::new("image", ["--", "/dev/null"]),
                 ],
             )),
+            // --print-json-schema conflicts with input
+            flat_map_collect(insert(
+                args.clone(),
+                vec![
+                    CliOption::new("print-json-schema", ["--print-schema", "json"]),
+                    CliOption::new("image", ["/dev/null"]),
+                ],
+            )),
+            // --print-json-schema conflicts with --format
+            flat_map_collect(insert(
+                args.clone(),
+                vec![
+                    CliOption::new("print-json-schema", ["--print-schema", "json"]),
+                    CliOption::new("format", ["--format=json"]),
+                ],
+            )),
+            // --print-json-schema conflicts with --hdr-key
+            flat_map_collect(insert(
+                args.clone(),
+                vec![
+                    CliOption::new("print-json-schema", ["--print-schema", "json"]),
+                    CliOption::new("hdr-key", ["--hdr-key", "/dev/null"]),
+                ],
+            )),
+            // --print-json-schema conflicts with --show-secrets
+            flat_map_collect(insert(
+                args,
+                vec![
+                    CliOption::new("print-json-schema", ["--print-schema", "json"]),
+                    CliOption::new("show-secrets", ["--show-secrets"]),
+                ],
+            )),
         ];
 
         let mut pvimg_valid_args = vec![];
