@@ -16,6 +16,7 @@
 
 #include "lib/util_base.h"
 #include "lib/util_file.h"
+#include "lib/util_fmt.h"
 #include "lib/util_opt.h"
 #include "lib/util_path.h"
 #include "lib/util_prg.h"
@@ -23,6 +24,19 @@
 #include "lib/util_scandir.h"
 #include "lib/zt_common.h"
 
+#define CHP_SHARED  "shared"
+#define CHP_STATE   "vary"
+#define CHP_PCHID   "pchid"
+#define CHP_TYPE    "type"
+#define CHP_CFG     "cfg"
+#define CHP_CMG     "cmg"
+#define CHP_ID      "chpid"
+
+static enum util_fmt_t fmt;
+static bool fmt_specified;
+
+#define OPT_FORMAT 262	/* --format */
+
 /*
  * Program configuration
  */
@@ -44,9 +58,85 @@ static const struct util_prg prg = {
 static struct util_opt opt_vec[] = {
 	UTIL_OPT_HELP,
 	UTIL_OPT_VERSION,
+	{
+		.option = { "format", required_argument, NULL, OPT_FORMAT},
+		.argument = "FORMAT",
+		.desc = "Output format (" FMT_TYPE_NAMES ")",
+		.flags = UTIL_OPT_FLAG_NOSHORT,
+	},
 	UTIL_OPT_END
 };
 
+/**
+ * Set the "--format" option
+ *
+ * @param[in] str	Format for structured output
+ */
+static void fmt_set(const char *str)
+{
+	if (!util_fmt_name_to_type(str, &fmt)) {
+		errx(EXIT_FAILURE, "Unknown format '%s', supported formats: %s\n", str,
+		     FMT_TYPE_NAMES);
+	}
+}
+
+/**
+ * Print buffer structure as formatted
+ *
+ * @param[in] rec     The buffer structure, where results are written to
+ */
+static void fmt_rec_print_formatted(struct util_rec *rec)
+{
+	const char *str_val, *key;
+	struct util_rec_fld *fld;
+	bool is_chid_external;
+	int ival = -1;
+
+	util_fmt_obj_start(FMT_ROW, "entry");
+	util_list_iterate(__util_rec_get_list(rec), fld) {
+		key = util_rec_fld_get_key(fld);
+		str_val = util_rec_get(rec, key);
+		if (!strcmp(str_val, "-")) {
+			util_fmt_pair(FMT_QUOTE | FMT_INVAL, key, "");
+		} else if (!strcmp(key, CHP_PCHID)) {
+			is_chid_external = (str_val[0] != '(');
+			sscanf(str_val, is_chid_external ? "%x" : "(%x)", &ival);
+			util_fmt_pair(FMT_DEFAULT, "chid", "%d", ival);
+			util_fmt_pair(FMT_DEFAULT, "chid_external", "%s", is_chid_external ?
+							"true" : "false");
+		} else if (!strcmp(key, CHP_ID)) {
+			util_fmt_pair(FMT_DEFAULT | FMT_QUOTE, key, "%s", str_val);
+		} else if (!strcmp(key, CHP_TYPE)) {
+			sscanf(str_val, "%x", &ival);
+			util_fmt_pair(FMT_DEFAULT, key, "%d", ival);
+		} else {
+			ival = atoi(str_val);
+			util_fmt_pair(FMT_DEFAULT, key, "%d", ival);
+		}
+	}
+	util_fmt_obj_end(); /* entry */
+}
+
+static void fmt_init(void)
+{
+	unsigned int flags = FMT_HANDLEINT | FMT_KEEPINVAL;
+
+	if (!fmt_specified)
+		return;
+	if (fmt == FMT_CSV)
+		flags |= FMT_NOMETA | FMT_QUOTEALL;
+	else
+		flags |= FMT_DEFAULT;
+	util_fmt_init(stdout, fmt, flags, 1);
+}
+
+static void fmt_end(void)
+{
+	if (!fmt_specified)
+		return;
+	util_fmt_exit();
+}
+
 /**
  * Read all attributes of a desired directory
  *
@@ -73,42 +163,42 @@ static void print_chpid(const char *chp_dir, unsigned int css_id,
 	path = util_path_sysfs("devices/css%x/%s", css_id, chp_dir);
 
 	/* chpid  */
-	util_rec_set(rec, "chpid", "%x.%02x", css_id, chp_id);
+	util_rec_set(rec, CHP_ID, "%x.%02x", css_id, chp_id);
 
 	/* vary */
 	util_file_read_line(buf, sizeof(buf), "%s/status", path);
 	if (strcmp(buf, "online") == 0)
-		util_rec_set(rec, "vary", "1");
+		util_rec_set(rec, CHP_STATE, "1");
 	else if (strcmp(buf, "offline") == 0)
-		util_rec_set(rec, "vary", "0");
+		util_rec_set(rec, CHP_STATE, "0");
 	else
-		util_rec_set(rec, "vary", "-");
+		util_rec_set(rec, CHP_STATE, "-");
 
 	/* configure */
 	if (util_file_read_line(buf, sizeof(buf), "%s/configure", path))
-		util_rec_set(rec, "cfg", "-");
+		util_rec_set(rec, CHP_CFG, "-");
 	else
-		util_rec_set(rec, "cfg", buf);
+		util_rec_set(rec, CHP_CFG, buf);
 
 	/* type */
 	if (util_file_read_line(buf, sizeof(buf), "%s/type", path))
-		util_rec_set(rec, "type", "%s", "-");
+		util_rec_set(rec, CHP_TYPE, "%s", "-");
 	else
-		util_rec_set(rec, "type", "%02lx", strtoul(buf, NULL, 16));
+		util_rec_set(rec, CHP_TYPE, "%02lx", strtoul(buf, NULL, 16));
 
 	/* cmg */
 	util_file_read_line(buf, sizeof(buf), "%s/cmg", path);
 	if ((strcmp(buf, "unknown") == 0) || (strlen(buf) == 0))
-		util_rec_set(rec, "cmg", "%-3s", "-");
+		util_rec_set(rec, CHP_CMG, "%s", "-");
 	else
-		util_rec_set(rec, "cmg", "%-3lx", strtoul(buf, NULL, 0));
+		util_rec_set(rec, CHP_CMG, "%-3lx", strtoul(buf, NULL, 0));
 
 	/* shared */
 	util_file_read_line(buf, sizeof(buf), "%s/shared", path);
 	if ((strcmp(buf, "unknown") == 0) || (strlen(buf) == 0))
-		util_rec_set(rec, "shared", "%s", "-");
+		util_rec_set(rec, CHP_SHARED, "%s", "-");
 	else
-		util_rec_set(rec, "shared", "%-6lx", strtoul(buf, NULL, 0));
+		util_rec_set(rec, CHP_SHARED, "%-6lx", strtoul(buf, NULL, 0));
 
 	/* chid */
 	util_file_read_line(buf, sizeof(buf), "%s/chid_external", path);
@@ -119,14 +209,18 @@ static void print_chpid(const char *chp_dir, unsigned int css_id,
 	util_file_read_line(buf, sizeof(buf), "%s/chid", path);
 	if (strlen(buf) != 0) {
 		if (chid_external)
-			util_rec_set(rec, "pchid", " %4s ", buf);
+			util_rec_set(rec, CHP_PCHID, " %4s ", buf);
 		else
-			util_rec_set(rec, "pchid", "(%4s)", buf);
+			util_rec_set(rec, CHP_PCHID, "(%4s)", buf);
 	} else {
-		util_rec_set(rec, "pchid", "%s", "-");
+		util_rec_set(rec, CHP_PCHID, "%s", "-");
+	}
+	if (!strlen(chp) || strcmp(util_rec_get(rec, CHP_ID), chp) == 0) {
+		if (fmt_specified)
+			fmt_rec_print_formatted(rec);
+		else
+			util_rec_print(rec);
 	}
-	if (!strlen(chp) || strcmp(util_rec_get(rec, "chpid"), chp) == 0)
-		util_rec_print(rec);
 	free(path);
 }
 
@@ -188,26 +282,33 @@ static void cmd_lschp(char *chp)
 	int i, count;
 	char *path;
 
+	fmt_init();
 	rec = util_rec_new_wide("=");
-	util_rec_def(rec, "chpid",  UTIL_REC_ALIGN_LEFT, 6, "CHPID");
-	util_rec_def(rec, "vary",   UTIL_REC_ALIGN_LEFT, 5, "Vary");
-	util_rec_def(rec, "cfg",    UTIL_REC_ALIGN_LEFT, 5, "Cfg.");
-	util_rec_def(rec, "type",   UTIL_REC_ALIGN_LEFT, 5, "Type");
-	util_rec_def(rec, "cmg",    UTIL_REC_ALIGN_LEFT, 4, "Cmg");
-	util_rec_def(rec, "shared", UTIL_REC_ALIGN_LEFT, 6, "Shared");
-	util_rec_def(rec, "pchid",  UTIL_REC_ALIGN_LEFT, 6, " PCHID");
+	util_rec_def(rec, CHP_ID,	UTIL_REC_ALIGN_LEFT, 6, "CHPID");
+	util_rec_def(rec, CHP_STATE,	UTIL_REC_ALIGN_LEFT, 5, "Vary");
+	util_rec_def(rec, CHP_CFG,	UTIL_REC_ALIGN_LEFT, 5, "Cfg.");
+	util_rec_def(rec, CHP_TYPE,	UTIL_REC_ALIGN_LEFT, 5, "Type");
+	util_rec_def(rec, CHP_CMG,	UTIL_REC_ALIGN_LEFT, 4, "Cmg");
+	util_rec_def(rec, CHP_SHARED,	UTIL_REC_ALIGN_LEFT, 6, "Shared");
+	util_rec_def(rec, CHP_PCHID,	UTIL_REC_ALIGN_LEFT, 6, " PCHID");
 
-	util_rec_print_hdr(rec);
+	if (!fmt_specified)
+		util_rec_print_hdr(rec);
 	/*
 	 * Iterate over each "/sys/devices/css.*"
 	 */
 	path = util_path_sysfs("devices");
 	count = util_scandir(&de_vec, alphasort, path, "^css[[:xdigit:]]{1,2}$");
+	if (fmt_specified)
+		util_fmt_obj_start(FMT_LIST, "channel_paths");
 	for (i = 0; i < count; i++)
 		print_css(de_vec[i]->d_name, rec, chp);
+	if (fmt_specified)
+		util_fmt_obj_end(); /* channel_paths */
 	util_ptr_vec_free((void **) de_vec, count);
 	free(path);
 	util_rec_free(rec);
+	fmt_end();
 }
 
 #define CHP_LEN		4
@@ -234,6 +335,10 @@ int main(int argc, char *argv[])
 		case 'v':
 			util_prg_print_version();
 			return EXIT_SUCCESS;
+		case OPT_FORMAT:
+			fmt_specified = true;
+			fmt_set(argv[optind - 1]);
+			break;
 		default:
 			util_opt_print_parse_error(c, argv);
 			return EXIT_FAILURE;
