@@ -20,7 +20,6 @@
 #include <unistd.h>
 
 #include "lib/util_libc.h"
-#include "lib/util_panic.h"
 
 #include "misc.h"
 
@@ -59,20 +58,14 @@ char *misc_link_target(const char *fmt, ...)
 {
 	char *lnk, *path;
 	va_list ap;
-	ssize_t rc;
 
-	path = util_malloc(PATH_MAX);
 	/* Construct the file name */
 	UTIL_VASPRINTF(&lnk, fmt, ap);
-	rc = readlink(lnk, path, PATH_MAX);
+	path = util_readlink(lnk);
 	free(lnk);
-	if (rc < 0) {
-		free(path);
+	if (!path)
 		return NULL;
-	}
-	util_assert(rc < (PATH_MAX - 1),
-		    "Internal error: Symlink name too long");
-	path[rc] = '\0';
+
 	return path;
 }
 
@@ -85,7 +78,7 @@ char *misc_link_target(const char *fmt, ...)
  * @param[in]	fmt	Format string for path
  * @param[in]	...	Variable arguments for format string
  *
- * @retval	!0	Number of string elemnts added to argz array
+ * @retval	!0	Number of string elements added to argz array
  * @retval	0	File is empty or cannot be processed
  */
 int misc_argz_add_from_file(char **argz, size_t *argz_len, const char *fmt, ...)
@@ -138,4 +131,3 @@ ssize_t misc_read_buf(int fd, char *buf, size_t count)
 	}
 	return done;
 }
-
