@@ -16,6 +16,7 @@
 #include "job.h"
 #include "misc.h"
 #include "zipl.h"
+#include "boot.h"
 #include "boot/boot_defs.h"
 
 #define NR_PROGRAM_TABLES NR_BLKPTR_FORMATS
@@ -52,6 +53,11 @@ struct component_loc {
 struct component_footer {
 	component_type type;
 	const char *desc;
+	int fs_block_aligned; /* if true, then the component should
+			       * be aligned to fs_block_size boundary
+			       * in the bootmap file. Otherwise, to
+			       * phy_block_size boundary.
+			       */
 };
 
 struct program_component {
@@ -66,18 +72,25 @@ struct program_table {
 	blocknum_t stage1b_count;
 };
 
-/* Bootloader Installation Set */
-struct install_set {
+/* A part of Bootloader Installation Set specific for an individual mirror */
+struct install_set_mirror {
 	struct program_table tables[NR_PROGRAM_TABLES];
 	struct program_component *components[NR_PROGRAM_COMPONENTS];
+	char *basetmp;
+	unsigned int print_details:1;
+	unsigned int skip_prepare_blocklist:1;
+};
+
+/* Bootloader Installation Set */
+struct install_set {
 	int nr_menu_entries;
 	struct misc_fd mfd;
-	char *basetmp[MAX_TARGETS];
+	struct install_set_mirror mirrors[MAX_TARGETS];
+	struct file_range comp_reg[NR_PROGRAM_COMPONENTS][BOOT_MENU_ENTRIES];
 	char *filename;
+	unsigned int skip_prepare_device:1;
 	unsigned int tmp_filename_created:1;
-	unsigned int skip_prepare:1;
-	unsigned int print_details:1;
-	struct disk_info *info;
+	struct device_info *info;
 	disk_blockptr_t scsi_dump_sb_blockptr;
 };
 
@@ -106,16 +119,36 @@ static inline const char *component_desc_by_id(enum program_component_id id)
 	return component_footers[id].desc;
 }
 
+static inline int fs_block_aligned_by_id(enum program_component_id id)
+{
+	return component_footers[id].fs_block_aligned;
+}
+
 static inline struct program_component *get_component(struct install_set *bis,
+						      int mirror_id,
 						      int i, int j)
 {
-	return bis->components[i] + j;
+	return bis->mirrors[mirror_id].components[i] + j;
+}
+
+/*
+ * Get a component as a region in the bootmap file
+ */
+static inline struct file_range *get_component_range(struct install_set *bis,
+						     int comp_id, int menu_idx)
+{
+	return &bis->comp_reg[comp_id][menu_idx];
+}
+
+static inline struct file_range *get_envblk_range(struct install_set *bis)
+{
+	return get_component_range(bis, COMPONENT_ID_ENVBLK, 0);
 }
 
 int prepare_bootloader(struct job_data *job, struct install_set *bis);
 int install_bootloader(struct job_data *job, struct install_set *bis);
 int post_install_bootloader(struct job_data *job, struct install_set *bis);
-void free_bootloader(struct install_set *bis);
+void free_bootloader(struct install_set *bis, struct job_data *job);
 int install_tapeloader(const char* device, const char* image,
 		       const char* parmline, const char* ramdisk,
 		       address_t image_addr, address_t parm_addr,
@@ -127,11 +160,13 @@ int install_mvdump(char* const device[], struct job_target_data* target,
 
 int install_fba_stage1b(struct misc_fd *mfd, disk_blockptr_t **stage1b_list,
 			blocknum_t *stage1b_count, disk_blockptr_t *stage2_list,
-			blocknum_t stage2_count, struct disk_info *info);
+			blocknum_t stage2_count, int fs_block_size,
+			struct disk_info *info);
 int install_eckd_stage1b(struct misc_fd *mfd, disk_blockptr_t **stage1b_list,
 			 blocknum_t *stage1b_count,
 			 disk_blockptr_t *stage2_list,
-			 blocknum_t stage2_count, struct disk_info *info);
+			 blocknum_t stage2_count, int fs_block_size,
+			 struct disk_info *info);
 int rewind_tape(int fd);
 
 #endif /* INSTALL_H */
