@@ -104,12 +104,13 @@ read_block_by_offset(int fd, int blksize, uint64_t offset, char *buffer)
 	return 0;
 }
 
-static int determine_virtblk_type(struct disk_info *data,
+static int determine_virtblk_type(struct device_info *dev_info,
 				  const struct stat *stats)
 {
+	struct disk_info *data = &dev_info->base[FIRST_MIRROR_ID];
+	int fd, rc, shift, sb;
 	char *device;
 	char *buffer;
-	int fd, rc, shift, sb;
 
 	rc = 0;
 	buffer = (char *) malloc(data->phy_block_size);
@@ -131,9 +132,9 @@ static int determine_virtblk_type(struct disk_info *data,
 	if (data->geo.heads == 15) {
 		/* assume DASD */
 		data->partnum = stats->st_rdev & DASD_PARTN_MASK;
-		data->device = stats->st_rdev & ~DASD_PARTN_MASK;
+		dev_info->device = stats->st_rdev & ~DASD_PARTN_MASK;
 
-		rc = misc_temp_dev(data->device, 1, &device);
+		rc = misc_temp_dev(dev_info->device, 1, &device);
 		if (rc)
 			goto out_err;
 
@@ -167,7 +168,7 @@ static int determine_virtblk_type(struct disk_info *data,
 	} else {
 		data->type = disk_type_scsi;
 		data->partnum = stats->st_rdev & SCSI_PARTN_MASK;
-		data->device = stats->st_rdev & ~SCSI_PARTN_MASK;
+		dev_info->device = stats->st_rdev & ~SCSI_PARTN_MASK;
 	}
 
 out_err:
@@ -195,6 +196,8 @@ static int set_target_parameters(FILE *fh, struct job_target_data *td)
 	char *error;
 	int i;
 
+	/* reset array of target parameters */
+	memset(td->targets, 0, sizeof(td->targets));
 	/**
 	 * Process a stream of 'key=value' pairs and distribute
 	 * them into groups.
@@ -284,65 +287,28 @@ error:
 	return -1;
 }
 
-static void print_base_disk_params(struct job_target_data *td, int index)
-{
-	disk_type_t type = get_targettype(td, index);
-
-	if (!verbose)
-		return;
-	{
-		fprintf(stderr, "Base disk '%s':\n", get_targetbase(td, index));
-		fprintf(stderr, "  layout........: %s\n", disk_get_type_name(type));
-	}
-	if (disk_type_is_eckd(type)) {
-		fprintf(stderr, "  heads.........: %u\n", get_targetheads(td, index));
-		fprintf(stderr, "  sectors.......: %u\n", get_targetsectors(td, index));
-		fprintf(stderr, "  cylinders.....: %u\n", get_targetcylinders(td, index));
-	}
-	{
-		fprintf(stderr, "  start.........: %lu\n", get_targetoffset(td, index));
-		fprintf(stderr, "  blksize.......: %u\n", get_targetblocksize(td, index));
-	}
-}
-
 /**
  * Set disk info using ready target parameters provided either by
  * user, or by script
  */
-static int disk_set_info_by_hint(struct job_target_data *td,
-				 struct disk_info *data, int fd)
+static int device_set_info_by_hint(struct job_target_data *td,
+				   struct device_info *data, int fd)
 {
 	int majnum, minnum;
 	struct stat stats;
 	int i;
-	/*
-	 * Currently multiple base disks with different parameters
-	 * are not supported
-	 */
-	data->devno = -1;
-	data->phy_block_size = get_targetblocksize(td, 0);
-	data->type = get_targettype(td, 0);
 
 	assert(td->nr_targets != 0);
-	for (i = 1; i < td->nr_targets; i++) {
-		if (data->type != get_targettype(td, i) ||
-		    data->phy_block_size != get_targetblocksize(td, i)) {
-			print_base_disk_params(td, 0);
-			print_base_disk_params(td, i);
-			error_reason("Inconsistent base disk geometry in target device");
-			return -1;
-		}
-	}
-	data->partnum = 0;
-	data->targetbase_def = undefined;
-
+	/* set devno, type, phy_block_size */
 	for (i = 0; i < td->nr_targets; i++) {
-		definition_t defined_as;
+		data->base[i].devno = -1;
+		data->base[i].type = get_targettype(td, i);
+		data->base[i].phy_block_size = get_targetblocksize(td, i);
 
 		if (sscanf(get_targetbase(td, i),
 			   "%d:%d", &majnum, &minnum) == 2) {
-			data->basedisks[i] = makedev(majnum, minnum);
-			defined_as = defined_as_device;
+			data->base[i].disk = makedev(majnum, minnum);
+			data->base[i].targetbase_def = defined_as_device;
 		} else {
 			if (stat(get_targetbase(td, i), &stats)) {
 				error_reason(strerror(errno));
@@ -356,47 +322,51 @@ static int disk_set_info_by_hint(struct job_target_data *td,
 					     get_targetbase(td, i));
 				return -1;
 			}
-			data->basedisks[i] = stats.st_rdev;
-			defined_as = defined_as_name;
+			data->base[i].disk = stats.st_rdev;
+			data->base[i].targetbase_def = defined_as_name;
 		}
-		if (data->targetbase_def != undefined &&
-		    data->targetbase_def != defined_as) {
+		if (data->base[i].targetbase_def !=
+		    data->base[0].targetbase_def) {
 			error_reason("Target base disks are defined by different ways");
 			return -1;
 		}
-		data->targetbase_def = defined_as;
+		data->base[i].partnum = 0;
+		if (data->base[i].type == disk_type_scsi &&
+		    ioctl(fd, NVME_IOCTL_ID) >= 0)
+			data->base[i].is_nvme = 1;
 	}
-	if (data->type == disk_type_scsi && ioctl(fd, NVME_IOCTL_ID) >= 0)
-		data->is_nvme = 1;
 	return 0;
 }
 
 /**
  * Calculate target parameters in the case when no hints were provided
  */
-static int disk_set_info_auto(struct disk_info *data,
+static int disk_set_info_auto(struct device_info *dev_info,
 			      const struct stat *stats, int fd)
 {
+	struct disk_info *data = &dev_info->base[FIRST_MIRROR_ID];
 	struct dasd_information dasd_info;
 
 	if (ioctl(fd, BLKSSZGET, &data->phy_block_size)) {
 		error_reason("Could not get blocksize");
 		return -1;
 	}
-	if (!data->drv_name) {
+	if (!dev_info->drv_name) {
 		/* Driver name cannot be read */
 		if (ioctl(fd, BIODASDINFO, &dasd_info)) {
 			data->devno = -1;
 			if (data->geo.start) {
 				/* SCSI partition */
 				data->type = disk_type_scsi;
-				data->partnum = stats->st_rdev & SCSI_PARTN_MASK;
-				data->device = stats->st_rdev & ~SCSI_PARTN_MASK;
+				data->partnum =
+					stats->st_rdev & SCSI_PARTN_MASK;
+				dev_info->device =
+					stats->st_rdev & ~SCSI_PARTN_MASK;
 			} else {
 				/* SCSI disk */
 				data->type = disk_type_scsi;
 				data->partnum = 0;
-				data->device = stats->st_rdev;
+				dev_info->device = stats->st_rdev;
 			}
 		} else {
 			/* DASD */
@@ -404,9 +374,9 @@ static int disk_set_info_auto(struct disk_info *data,
 			if (disk_determine_dasd_type(data, dasd_info))
 				return -1;
 			data->partnum = stats->st_rdev & DASD_PARTN_MASK;
-			data->device = stats->st_rdev & ~DASD_PARTN_MASK;
+			dev_info->device = stats->st_rdev & ~DASD_PARTN_MASK;
 		}
-	} else if (strcmp(data->drv_name, UTIL_PROC_DEV_ENTRY_DASD) == 0) {
+	} else if (strcmp(dev_info->drv_name, UTIL_PROC_DEV_ENTRY_DASD) == 0) {
 		/* Driver name is 'dasd' */
 		if (ioctl(fd, BIODASDINFO, &dasd_info)) {
 			error_reason("Could not determine DASD type");
@@ -416,27 +386,29 @@ static int disk_set_info_auto(struct disk_info *data,
 		if (disk_determine_dasd_type(data, dasd_info))
 			return -1;
 		data->partnum = stats->st_rdev & DASD_PARTN_MASK;
-		data->device = stats->st_rdev & ~DASD_PARTN_MASK;
-	} else if (strcmp(data->drv_name, UTIL_PROC_DEV_ENTRY_SD) == 0) {
+		dev_info->device = stats->st_rdev & ~DASD_PARTN_MASK;
+	} else if (strcmp(dev_info->drv_name, UTIL_PROC_DEV_ENTRY_SD) == 0) {
 		/* Driver name is 'sd' */
 		data->devno = -1;
 		data->type = disk_type_scsi;
 		data->partnum = stats->st_rdev & SCSI_PARTN_MASK;
-		data->device = stats->st_rdev & ~SCSI_PARTN_MASK;
+		dev_info->device = stats->st_rdev & ~SCSI_PARTN_MASK;
 
-	} else if (strcmp(data->drv_name, UTIL_PROC_DEV_ENTRY_VIRTBLK) == 0) {
+	} else if (strcmp(dev_info->drv_name,
+			  UTIL_PROC_DEV_ENTRY_VIRTBLK) == 0) {
 		/* Driver name is 'virtblk' */
 		if (ioctl(fd, HDIO_GETGEO, &data->geo) != 0)
 			perror("Could not retrieve disk geometry information.");
 		if (ioctl(fd, BLKSSZGET, &data->phy_block_size) != 0)
 			perror("Could not retrieve blocksize information.");
 
-		if (determine_virtblk_type(data, stats)) {
+		if (determine_virtblk_type(dev_info, stats)) {
 			error_reason("Virtblk device type not clearly "
 				     "determined.");
 			return -1;
 		}
-	} else if (strcmp(data->drv_name, UTIL_PROC_DEV_ENTRY_BLKEXT) == 0 &&
+	} else if (strcmp(dev_info->drv_name,
+			  UTIL_PROC_DEV_ENTRY_BLKEXT) == 0 &&
 		   ioctl(fd, NVME_IOCTL_ID) >= 0) {
 		/* NVMe path, driver name is 'blkext' */
 		data->devno = -1;
@@ -444,18 +416,20 @@ static int disk_set_info_auto(struct disk_info *data,
 		data->is_nvme = 1;
 
 		if (util_sys_dev_is_partition(stats->st_rdev)) {
-			if (util_sys_get_base_dev(stats->st_rdev, &data->device))
+			if (util_sys_get_base_dev(stats->st_rdev,
+						  &dev_info->device))
 				return -1;
 			data->partnum = util_sys_get_partnum(stats->st_rdev);
 			if (data->partnum == -1)
 				return -1;
 		} else {
-			data->device = stats->st_rdev;
+			dev_info->device = stats->st_rdev;
 			data->partnum = 0;
 		}
 	} else {
 		/* Driver name is unknown */
-		error_reason("Unsupported device driver '%s'", data->drv_name);
+		error_reason("Unsupported device driver '%s'",
+			     dev_info->drv_name);
 		return -1;
 	}
 	return 0;
@@ -488,7 +462,7 @@ static void set_source_type(struct job_target_data *td,
 	td->source = source_auto;
 }
 
-static void set_driver_name(int fd, struct disk_info *info, dev_t device)
+static void set_driver_name(int fd, struct device_info *info, dev_t device)
 {
 	struct util_proc_dev_entry dev_entry;
 
@@ -555,30 +529,17 @@ static int run_targetbase_script(struct job_target_data *td,
  * Note: geo.start contains a sector number offset measured in
  * physical blocks, not sectors (512 bytes)
  */
-static int disk_set_geometry_by_hint(struct job_target_data *td,
-				     struct disk_info *data)
+static int device_set_geometry_by_hint(struct job_target_data *td,
+				       struct device_info *data)
 {
 	int i;
-	/*
-	 * Currently multiple base disks with different parameters
-	 * are not supported
-	 */
-	data->geo.heads = get_targetheads(td, 0);
-	data->geo.sectors = get_targetsectors(td, 0);
-	data->geo.cylinders = get_targetcylinders(td, 0);
-	data->geo.start = get_targetoffset(td, 0);
 
 	assert(td->nr_targets != 0);
-	for (i = 1; i < td->nr_targets; i++) {
-		if (data->geo.heads     != get_targetheads(td, i) ||
-		    data->geo.sectors   != get_targetsectors(td, i) ||
-		    data->geo.cylinders != get_targetcylinders(td, i) ||
-		    data->geo.start     != get_targetoffset(td, i)) {
-			print_base_disk_params(td, 0);
-			print_base_disk_params(td, i);
-			error_reason("Inconsistent base disk geometry in target device");
-			return -1;
-		}
+	for (i = 0; i < td->nr_targets; i++) {
+		data->base[i].geo.heads = get_targetheads(td, i);
+		data->base[i].geo.sectors = get_targetsectors(td, i);
+		data->base[i].geo.cylinders = get_targetcylinders(td, i);
+		data->base[i].geo.start = get_targetoffset(td, i);
 	}
 	return 0;
 }
@@ -603,7 +564,6 @@ static int disk_set_info_complete(struct job_target_data *td,
 				  struct disk_info *data,
 				  struct stat *stats, int fd)
 {
-	struct util_proc_part_entry part_entry;
 	long devsize;
 
 	/* Get size of device in sectors (512 byte) */
@@ -631,15 +591,22 @@ static int disk_set_info_complete(struct job_target_data *td,
 			data->geo.start / (data->phy_block_size / 512);
 	if (data->partnum != 0)
 		data->partition = stats->st_rdev;
+	return 0;
+}
+
+static int device_set_info_complete(struct device_info *dev_info)
+{
+	struct util_proc_part_entry part_entry;
+
 	/* Try to get device name */
-	if (util_proc_part_get_entry(data->device, &part_entry) == 0) {
-		data->name = misc_strdup(part_entry.name);
+	if (util_proc_part_get_entry(dev_info->device, &part_entry) == 0) {
+		dev_info->name = misc_strdup(part_entry.name);
 		util_proc_part_free_entry(&part_entry);
-		if (data->name == NULL)
+		if (!dev_info->name)
 			return -1;
 	}
 	/* Initialize file system block size with invalid value */
-	data->fs_block_size = -1;
+	dev_info->fs_block_size = -1;
 	return 0;
 }
 
@@ -663,16 +630,17 @@ static int disk_set_info_complete(struct job_target_data *td,
  * To exclude any user assumptions about the DEVICE, this function
  * should be called with TD pointing to a zeroed structure.
  *
- * DEVICE: logical, or physical device, optionally formated with a
+ * DEVICE: logical, or physical device, optionally formatted with a
  * file system.
  */
-int disk_get_info(const char *device, struct job_target_data *td,
-		  struct disk_info **info)
+int device_get_info(const char *device, struct job_target_data *td,
+		    struct device_info **info)
 {
 	char *script_file = NULL;
-	struct disk_info *data;
+	struct device_info *data;
 	struct stat stats;
 	int fd;
+	int i;
 
 	if (stat(device, &stats)) {
 		error_reason(strerror(errno));
@@ -683,10 +651,10 @@ int disk_get_info(const char *device, struct job_target_data *td,
 		error_reason(strerror(errno));
 		return -1;
 	}
-	data = (struct disk_info *)misc_malloc(sizeof(struct disk_info));
+	data = (struct device_info *)misc_malloc(sizeof(struct device_info));
 	if (!data)
 		goto error;
-	memset((void *)data, 0, sizeof(struct disk_info));
+	memset((void *)data, 0, sizeof(struct device_info));
 	set_driver_name(fd, data, stats.st_rdev);
 	set_source_type(td, data->drv_name, &script_file);
 	switch (td->source) {
@@ -696,9 +664,9 @@ int disk_get_info(const char *device, struct job_target_data *td,
 		/* target parameters were set by the script output */
 		assert(target_parameters_are_set(td));
 
-		if (disk_set_geometry_by_hint(td, data))
+		if (device_set_geometry_by_hint(td, data))
 			goto error;
-		if (disk_set_info_by_hint(td, data, fd))
+		if (device_set_info_by_hint(td, data, fd))
 			goto error;
 		data->device = stats.st_rdev;
 		break;
@@ -709,20 +677,20 @@ int disk_get_info(const char *device, struct job_target_data *td,
 		 */
 		assert(target_parameters_are_set(td));
 
-		if (disk_set_geometry_by_hint(td, data))
+		if (device_set_geometry_by_hint(td, data))
 			goto error;
-		if (disk_set_info_by_hint(td, data, fd))
+		if (device_set_info_by_hint(td, data, fd))
 			goto error;
 		/*
 		 * multiple base disks are not supported
 		 * with this source type
 		 */
 		assert(td->nr_targets == 1);
-		data->device = data->basedisks[0];
+		data->device = data->base[FIRST_MIRROR_ID].disk;
 		break;
 	case source_auto:
 		/* no ready target parameters are available */
-		if (disk_set_geometry_auto(fd, data))
+		if (disk_set_geometry_auto(fd, &data->base[FIRST_MIRROR_ID]))
 			goto error;
 		if (disk_set_info_auto(data, &stats, fd))
 			goto error;
@@ -730,13 +698,17 @@ int disk_get_info(const char *device, struct job_target_data *td,
 		 * multiple base disks are not supported
 		 * with this source type
 		 */
-		data->basedisks[0] = data->device;
+		data->base[FIRST_MIRROR_ID].disk = data->device;
 		td->nr_targets = 1;
 		break;
 	default:
 		assert(0);
 	}
-	if (disk_set_info_complete(td, data, &stats, fd))
+	for (i = 0; i < td->nr_targets; i++) {
+		if (disk_set_info_complete(td, &data->base[i], &stats, fd))
+			goto error;
+	}
+	if (device_set_info_complete(data))
 		goto error;
 	free(script_file);
 	close(fd);
@@ -749,8 +721,7 @@ error:
 	return -1;
 }
 
-int
-disk_is_tape(const char* device)
+static int disk_is_tape(const char *device)
 {
 	int fd, rc = 0;
 
@@ -772,21 +743,32 @@ disk_is_tape(const char* device)
  * partition, etc). In case of success the resulted disk type is
  * stored in EXT_TYPE.
  */
-int disk_get_ext_type(const char *device, struct disk_ext_type *ext_type)
+int dump_disk_get_ext_type(const char *device, struct disk_ext_type *ext_type)
 {
 	struct job_target_data tmp = {.source = source_unknown};
+	struct device_info *dev_info;
 	struct disk_info *info;
 
-	if (disk_get_info(device, &tmp, &info))
+	if (disk_is_tape(device)) {
+		ext_type->is_tape = 1;
+		return 0;
+	}
+	if (device_get_info(device, &tmp, &dev_info))
 		return -1;
+	info = &dev_info->base[0];
 	ext_type->type = info->type;
 	ext_type->is_nvme = info->is_nvme;
 
-	disk_free_info(info);
+	device_free_info(dev_info);
 	free_target_data(&tmp);
 	return 0;
 }
 
+int disk_type_is_tape(struct disk_ext_type *ext_type)
+{
+	return ext_type->is_tape;
+}
+
 int disk_type_is_scsi(struct disk_ext_type *ext_type)
 {
 	return ext_type->type == disk_type_scsi;
@@ -811,7 +793,7 @@ int disk_type_is_eckd(disk_type_t type)
 /**
  * Retrieve and set block size of the file system which contains FILENAME
  */
-int disk_info_set_fs_block(const char *filename, struct disk_info *info)
+int device_info_set_fs_block(const char *filename, struct device_info *dinfo)
 {
 	int blocksize;
 	int fd;
@@ -830,7 +812,7 @@ int disk_info_set_fs_block(const char *filename, struct disk_info *info)
 			     filename);
 		return -1;
 	}
-	info->fs_block_size = blocksize;
+	dinfo->fs_block_size = blocksize;
 	return 0;
 }
 
@@ -838,9 +820,9 @@ int disk_info_set_fs_block(const char *filename, struct disk_info *info)
  * Retrieve disk info of the device which contains FILENAME
  * and set the filesystem block size
  */
-int disk_get_info_from_file(const char *filename,
-			    struct job_target_data *target,
-			    struct disk_info **info)
+int device_get_info_from_file(const char *filename,
+			      struct job_target_data *target,
+			      struct device_info **info)
 {
 	struct stat stats;
 	char *device;
@@ -851,15 +833,15 @@ int disk_get_info_from_file(const char *filename,
 	}
 	if (misc_temp_dev(stats.st_dev, 1, &device))
 		return -1;
-	if (disk_get_info(device, target, info)) {
+	if (device_get_info(device, target, info)) {
 		misc_free_temp_dev(device);
 		return -1;
 	}
 	misc_free_temp_dev(device);
-	return disk_info_set_fs_block(filename, *info);
+	return device_info_set_fs_block(filename, *info);
 }
 
-void disk_free_info(struct disk_info *info)
+void device_free_info(struct device_info *info)
 {
 	if (!info)
 		return;
@@ -877,28 +859,29 @@ void disk_free_info(struct disk_info *info)
  * otherwise. */
 static int
 disk_get_blocknum(int fd, int fd_is_basedisk, blocknum_t logical,
-		  blocknum_t* physical, struct disk_info* info)
+		  blocknum_t *physical, int fs_block_size,
+		  struct disk_info *disk_info)
 {
 	blocknum_t phy_per_fs;
 	blocknum_t mapped;
 	int subblock;
 
 	/* No file system: partition or raw disk */
-	if (info->fs_block_size == -1) {
+	if (fs_block_size == -1) {
 		if (fd_is_basedisk)
 			*physical = logical;
 		else
-			*physical = logical + info->geo.start;
+			*physical = logical + disk_info->geo.start;
 		return 0;
 	}
 	/*
 	 * Get mapping in file system blocks
 	 */
-	phy_per_fs = info->fs_block_size / info->phy_block_size;
+	phy_per_fs = fs_block_size / disk_info->phy_block_size;
 	subblock = logical % phy_per_fs;
 
-	if (fs_map(fd, logical * info->phy_block_size,
-		   &mapped, info->fs_block_size) != 0)
+	if (fs_map(fd, logical * disk_info->phy_block_size,
+		   &mapped, fs_block_size) != 0)
 		return -1;
 	if (mapped == 0) {
 		/* This is a hole in the file */
@@ -907,7 +890,7 @@ disk_get_blocknum(int fd, int fd_is_basedisk, blocknum_t logical,
 		/* Convert file system block to physical */
 		*physical = mapped * phy_per_fs + subblock;
 		/* Add partition start */
-		*physical += info->geo.start;
+		*physical += disk_info->geo.start;
 	}
 	return 0;
 }
@@ -916,7 +899,7 @@ disk_get_blocknum(int fd, int fd_is_basedisk, blocknum_t logical,
 /* Return the cylinder on which the block number BLOCKNUM is stored on the
  * CHS device identified by INFO. */
 int
-disk_cyl_from_blocknum(blocknum_t blocknum, struct disk_info* info)
+disk_cyl_from_blocknum(blocknum_t blocknum, struct disk_info *info)
 {
 	return blocknum / (info->geo.heads * info->geo.sectors);
 }
@@ -925,7 +908,7 @@ disk_cyl_from_blocknum(blocknum_t blocknum, struct disk_info* info)
 /* Return the head on which the block number BLOCKNUM is stored on the
  * CHS device identified by INFO. */
 int
-disk_head_from_blocknum(blocknum_t blocknum, struct disk_info* info)
+disk_head_from_blocknum(blocknum_t blocknum, struct disk_info *info)
 {
 	return (blocknum / info->geo.sectors) % info->geo.heads;
 }
@@ -934,7 +917,7 @@ disk_head_from_blocknum(blocknum_t blocknum, struct disk_info* info)
 /* Return the sector on which the block number BLOCKNUM is stored on the
  * CHS device identified by INFO. */
 int
-disk_sec_from_blocknum(blocknum_t blocknum, struct disk_info* info)
+disk_sec_from_blocknum(blocknum_t blocknum, struct disk_info *info)
 {
 	return blocknum % info->geo.sectors + 1;
 }
@@ -945,7 +928,7 @@ disk_sec_from_blocknum(blocknum_t blocknum, struct disk_info* info)
  * layout. */
 void
 disk_blockptr_from_blocknum(disk_blockptr_t* ptr, blocknum_t blocknum,
-			    struct disk_info* info)
+			    struct disk_info *info)
 {
 	switch (info->type) {
 	case disk_type_scsi:
@@ -986,8 +969,9 @@ disk_blockptr_from_blocknum(disk_blockptr_t* ptr, blocknum_t blocknum,
  * otherwise. On success OFFSET contains offset of the first written byte
  */
 static int
-disk_write_block_aligned_base(struct misc_fd *mfd, int is_base_disk, const void *data,
-			      size_t bytecount, disk_blockptr_t *block,
+disk_write_block_aligned_base(struct misc_fd *mfd, int is_base_disk,
+			      const void *data, size_t bytecount,
+			      disk_blockptr_t *block, int fs_block_size,
 			      struct disk_info *info, int align, off_t *offset)
 {
 	blocknum_t current_block;
@@ -1021,7 +1005,7 @@ disk_write_block_aligned_base(struct misc_fd *mfd, int is_base_disk, const void
 	if (block != NULL) {
 		/* Store block pointer */
 		if (disk_get_blocknum(mfd->fd, is_base_disk, current_block,
-				      &blocknum, info))
+				      &blocknum, fs_block_size, info))
 			return -1;
 		disk_blockptr_from_blocknum(block, blocknum, info);
 	}
@@ -1030,11 +1014,13 @@ disk_write_block_aligned_base(struct misc_fd *mfd, int is_base_disk, const void
 	return 0;
 }
 
-int disk_write_block_aligned(struct misc_fd *mfd, const void *data, size_t bytecount,
-			     disk_blockptr_t *block, struct disk_info *info)
+int disk_write_block_aligned(struct misc_fd *mfd, const void *data,
+			     size_t bytecount, disk_blockptr_t *block,
+			     int fs_block_size, struct disk_info *info)
 {
 	return disk_write_block_aligned_base(mfd, 0, data, bytecount, block,
-					     info, info->phy_block_size, NULL);
+					     fs_block_size, info,
+					     info->phy_block_size, NULL);
 }
 
 /**
@@ -1047,8 +1033,9 @@ int disk_write_block_aligned(struct misc_fd *mfd, const void *data, size_t bytec
  * otherwise.
  */
 blocknum_t
-disk_write_block_buffer_align(struct misc_fd *mfd, int fd_is_basedisk, const void *buffer,
-			      size_t bytecount, disk_blockptr_t **blocklist,
+disk_write_block_buffer_align(struct misc_fd *mfd, int fd_is_basedisk,
+			      const void *buffer, size_t bytecount,
+			      disk_blockptr_t **blocklist, int fs_block_size,
 			      struct disk_info *info, int align, off_t *offset)
 {
 	blocknum_t count;
@@ -1061,6 +1048,7 @@ disk_write_block_buffer_align(struct misc_fd *mfd, int fd_is_basedisk, const voi
 	count = (bytecount + info->phy_block_size - 1) / info->phy_block_size;
 	*blocklist = (disk_blockptr_t *)util_zalloc(sizeof(disk_blockptr_t) *
 						    count);
+
 	if (*blocklist == NULL) {
 		close(mfd->fd);
 		return 0;
@@ -1073,6 +1061,7 @@ disk_write_block_buffer_align(struct misc_fd *mfd, int fd_is_basedisk, const voi
 		rc = disk_write_block_aligned_base(mfd, fd_is_basedisk,
 					VOID_ADD(buffer, written),
 					chunk_size, &(*blocklist)[i],
+					fs_block_size,
 					info,
 					i == 0 ? align : info->phy_block_size,
 					&pos);
@@ -1085,12 +1074,14 @@ disk_write_block_buffer_align(struct misc_fd *mfd, int fd_is_basedisk, const voi
 }
 
 blocknum_t
-disk_write_block_buffer(struct misc_fd *mfd, int fd_is_basedisk, const void *buffer,
-			size_t bytecount, disk_blockptr_t **blocklist,
+disk_write_block_buffer(struct misc_fd *mfd, int fd_is_basedisk,
+			const void *buffer, size_t bytecount,
+			disk_blockptr_t **blocklist, int fs_block_size,
 			struct disk_info *info)
 {
 	return disk_write_block_buffer_align(mfd, fd_is_basedisk, buffer,
-					     bytecount, blocklist, info,
+					     bytecount, blocklist,
+					     fs_block_size, info,
 					     info->phy_block_size, NULL);
 }
 
@@ -1167,83 +1158,95 @@ char *disk_get_ipl_type(disk_type_t type, int is_dump)
 
 /* Return non-zero for ECKD large volumes. */
 int
-disk_is_large_volume(struct disk_info* info)
+disk_is_large_volume(struct disk_info *info)
 {
 	return (info->type == disk_type_eckd_ldl ||
 		info->type == disk_type_eckd_cdl) &&
 		info->geo.cylinders == 0xfffe;
 }
 
-
-/* Print textual representation of INFO contents. */
-void disk_print_info(struct disk_info *info, int source)
+static void disk_print_info(struct disk_info *info, int source)
 {
+	const char *prefix = "    ";
 	char footnote[4] = "";
 
 	prepare_footnote_ptr(source, footnote);
-	printf("  Device..........................: ");
-	disk_print_devt(info->device);
+	printf("%sDisk............................: ", prefix);
+	disk_print_devt(info->disk);
 	if (info->targetbase_def == defined_as_device)
 		printf("%s", footnote);
 	printf("\n");
 	if (info->partnum != 0) {
-		printf("  Partition.......................: ");
+		printf("%sPartition.......................: ", prefix);
 		disk_print_devt(info->partition);
 		printf("\n");
 	}
-	if (info->name) {
-		printf("  Device name.....................: %s",
-		       info->name);
-		if (info->targetbase_def == defined_as_name)
-			printf("%s", footnote);
-		printf("\n");
-	}
-	if (info->drv_name) {
-		printf("  Device driver name..............: %s\n",
-		       info->drv_name);
-	}
 	if (((info->type == disk_type_fba) ||
 	     (info->type == disk_type_diag) ||
 	     (info->type == disk_type_eckd_ldl) ||
 	     (info->type == disk_type_eckd_cdl)) &&
 	     (source == source_auto)) {
-		printf("  DASD device number..............: %04x\n",
-		       info->devno);
+		printf("%sDASD device number..............: %04x\n",
+		       prefix, info->devno);
 	}
-	printf("  Type............................: disk %s\n",
-	       (info->partnum != 0) ? "partition" : "device");
-	printf("  Disk layout.....................: %s%s\n",
-	       disk_get_type_name(info->type), footnote);
+	printf("%sType............................: disk %s\n",
+	       prefix, (info->partnum != 0) ? "partition" : "device");
+	printf("%sDisk layout.....................: %s%s\n",
+	       prefix, disk_get_type_name(info->type), footnote);
 	if (disk_type_is_eckd(info->type)) {
-		printf("  Geometry - heads................: %d%s\n",
-		       info->geo.heads, footnote);
-		printf("  Geometry - sectors..............: %d%s\n",
-		       info->geo.sectors, footnote);
+		printf("%sGeometry - heads................: %d%s\n",
+		       prefix, info->geo.heads, footnote);
+		printf("%sGeometry - sectors..............: %d%s\n",
+		       prefix, info->geo.sectors, footnote);
 		if (disk_is_large_volume(info)) {
 			/* ECKD large volume. There is not enough information
 			 * available in INFO to calculate disk cylinder size. */
-			printf("  Geometry - cylinders............: > 65534\n");
+			printf("%sGeometry - cylinders............: > 65534\n",
+			       prefix);
 		} else {
-			printf("  Geometry - cylinders............: %d%s\n",
-			       info->geo.cylinders, footnote);
+			printf("%sGeometry - cylinders............: %d%s\n",
+			       prefix, info->geo.cylinders, footnote);
 		}
 	}
-	printf("  Geometry - start................: %ld%s\n",
-	       info->geo.start, footnote);
-	if (info->fs_block_size >= 0)
-		printf("  File system block size..........: %d\n",
-		       info->fs_block_size);
-	printf("  Physical block size.............: %d%s\n",
-	       info->phy_block_size, footnote);
-	printf("  Device size in physical blocks..: %ld\n",
-	       (long) info->phy_blocks);
-	print_footnote_ref(source, "  ");
+	printf("%sGeometry - start................: %ld%s\n",
+	       prefix, info->geo.start, footnote);
+	printf("%sPhysical block size.............: %d%s\n",
+	       prefix, info->phy_block_size, footnote);
+	printf("%sDisk size in physical blocks....: %ld\n",
+	       prefix, (long)info->phy_blocks);
+	print_footnote_ref(source, prefix);
+}
+
+void device_print_info(struct device_info *this, struct job_target_data *td)
+{
+	int i;
+
+	printf("  Device............................: ");
+	disk_print_devt(this->device);
+	printf("\n");
+
+	if (this->name) {
+		printf("  Device name.......................: %s",
+		       this->name);
+		printf("\n");
+	}
+	if (this->drv_name) {
+		printf("  Device driver name................: %s\n",
+		       this->drv_name);
+	}
+	if (this->fs_block_size >= 0)
+		printf("  File system block size............: %d\n",
+		       this->fs_block_size);
+	for (i = 0; i < td->nr_targets; i++) {
+		printf("  Base %d:\n", i + 1);
+		disk_print_info(&this->base[i], td->source);
+	}
 }
 
 /* Check whether a block is a zero block which identifies a hole in a file.
  * Return non-zero if BLOCK is a zero block, 0 otherwise. */
 int
-disk_is_zero_block(disk_blockptr_t* block, struct disk_info* info)
+disk_is_zero_block(disk_blockptr_t *block, struct disk_info *info)
 {
 	switch (info->type) {
 	case disk_type_scsi:
@@ -1269,7 +1272,7 @@ disk_is_zero_block(disk_blockptr_t* block, struct disk_info* info)
  * blocks can be merged, 0 otherwise. */
 static int
 can_merge_blocks(disk_blockptr_t* first, disk_blockptr_t* second,
-		 struct disk_info* info)
+		 struct disk_info *info)
 {
 	int max_count;
 
@@ -1315,7 +1318,7 @@ can_merge_blocks(disk_blockptr_t* first, disk_blockptr_t* second,
  * type. */
 static void
 merge_blocks(disk_blockptr_t* first, disk_blockptr_t* second,
-	     struct disk_info* info)
+	     struct disk_info *info)
 {
 	switch (info->type) {
 	case disk_type_scsi:
@@ -1338,7 +1341,7 @@ merge_blocks(disk_blockptr_t* first, disk_blockptr_t* second,
  * number of elements in the list. */
 blocknum_t
 disk_compact_blocklist(disk_blockptr_t* list, blocknum_t count,
-		       struct disk_info* info)
+		       struct disk_info *info)
 {
 	blocknum_t i;
 	blocknum_t last;
@@ -1365,8 +1368,8 @@ disk_compact_blocklist(disk_blockptr_t* list, blocknum_t count,
  */
 blocknum_t
 disk_get_blocklist_from_file(const char *filename, struct file_range *reg,
-			     disk_blockptr_t **blocklist,
-			     struct disk_info* info)
+			     disk_blockptr_t **blocklist, int fs_block_size,
+			     struct disk_info *info)
 {
 	struct stat stats;
 	int fd;
@@ -1419,7 +1422,8 @@ disk_get_blocklist_from_file(const char *filename, struct file_range *reg,
 	}
 	/* Build list */
 	for (i = 0; i < blk_count; i++) {
-		if (disk_get_blocknum(fd, 0, blk_off + i, &blocknum, info)) {
+		if (disk_get_blocknum(fd, 0, blk_off + i, &blocknum,
+				      fs_block_size, info)) {
 			close(fd);
 			return 0;
 		}
