@@ -29,6 +29,7 @@ struct keystore {
 #define PROP_NAME_KEY_TYPE		"key-type"
 #define PROP_NAME_CIPHER		"cipher"
 #define PROP_NAME_IV_MODE		"iv-mode"
+#define PROP_NAME_DIGEST		"digest"
 #define PROP_NAME_DESCRIPTION		"description"
 #define PROP_NAME_VOLUMES		"volumes"
 #define PROP_NAME_APQNS			"apqns"
@@ -46,6 +47,9 @@ struct keystore {
 #define PROP_NAME_KMS_XTS_KEY2_ID	"kms-xts-key2-id"
 #define PROP_NAME_KMS_XTS_KEY2_LABEL	"kms-xts-key2-label"
 
+#define KEY_TYPE_FILTER_AES		"AES"
+#define KEY_TYPE_FILTER_HMAC		"HMAC"
+
 struct keystore *keystore_new(const char *directory,
 			      struct kms_info *kms_info, bool verbose);
 
@@ -126,6 +130,12 @@ int keystore_crypttab(struct keystore *keystore, const char *volume_filter,
 		      const char *volume_type, const char *keyfile,
 		      size_t keyfile_offset, size_t keyfile_size, size_t tries);
 
+int keystore_integritysetup(struct keystore *keystore,
+			    const char *volume_filter,
+			    bool execute, bool batch_mode, bool open);
+
+int keystore_integritytab(struct keystore *keystore, const char *volume_filter);
+
 int keystore_convert_key(struct keystore *keystore, const char *name,
 			 const char *key_type, bool noapqncheck, bool quiet,
 			 bool exportable, int pkey_fd, struct ext_lib *lib);
