@@ -1623,6 +1623,134 @@ out:
 	return rc;
 }
 
+/**
+ * Generate a key verification pattern of a secure HMAC key by MACing the all
+ * zero message with the secure key using the AF_ALG interface
+ *
+ * @param[in] key           the secure key token
+ * @param[in] key_size      the size of the secure key
+ * @param[in] vp            buffer where the verification pattern is returned
+ * @param[in] vp_len        the size of the buffer
+ * @param[in] verbose       if true, verbose messages are printed
+ *
+ * @returns 0 on success, a negative errno in case of an error
+ */
+int generate_hmac_key_verification_pattern(const u8 *key,
+					   size_t key_size,
+					   char *vp, size_t vp_len,
+					   const char *cipher,
+					   bool verbose)
+{
+	int tfmfd = -1, opfd = -1, rc = 0, retry_count = 0;
+	char null_msg[MAC_ZERO_LEN];
+	char mac_zero[MAC_ZERO_LEN];
+	size_t i, bitsize;
+	int len;
+
+	struct sockaddr_alg sa = {
+		.salg_family = AF_ALG,
+		.salg_type = "hash",
+	};
+
+	if (vp_len < VERIFICATION_PATTERN_LEN) {
+		rc = -EMSGSIZE;
+		goto out;
+	}
+
+	if (cipher != NULL) {
+		util_strlcpy((char *)sa.salg_name, cipher,
+			     sizeof(sa.salg_name));
+	} else {
+		rc = get_key_bit_size(key, key_size, &bitsize);
+		if (rc != 0) {
+			pr_verbose(verbose, "Failed to get the key size");
+			goto out;
+		}
+		snprintf((char *)sa.salg_name, sizeof(sa.salg_name),
+			 "phmac(sha%lu)", bitsize / 2);
+	}
+
+	tfmfd = socket(AF_ALG, SOCK_SEQPACKET, 0);
+	if (tfmfd < 0) {
+		rc = -errno;
+		pr_verbose(verbose, "Failed to open an AF_ALG socket");
+		goto out;
+	}
+
+	if (bind(tfmfd, (struct sockaddr *)&sa, sizeof(sa)) < 0) {
+		rc = -errno;
+		pr_verbose(verbose, "Failed to bind the AF_ALG socket, "
+			   "salg_name='%s' ", sa.salg_name);
+		goto out;
+	}
+
+retry_setkey:
+	if (setsockopt(tfmfd, SOL_ALG, ALG_SET_KEY, key,
+		       key_size) < 0) {
+		rc = -errno;
+		pr_verbose(verbose, "Failed to set the key: %s",
+			   strerror(-rc));
+
+		/*
+		 * After a master key change, it can happen that the setkey
+		 * operation returns EINVAL or EAGAIN, although the key is
+		 * valid. This is a temporary situation and the operation will
+		 * succeed, once the firmware has completed some internal
+		 * processing related with the master key change.
+		 * Delay 1 second and retry up to 10 times.
+		 */
+		if ((rc == -EINVAL || rc == -EAGAIN) && retry_count < 10) {
+			pr_verbose(verbose, "Retrying after 1 second...");
+			retry_count++;
+			sleep(1);
+			goto retry_setkey;
+		}
+		goto out;
+	}
+	rc = 0;
+
+	opfd = accept(tfmfd, NULL, NULL);
+	if (opfd < 0) {
+		rc = -errno;
+		pr_verbose(verbose, "Failed to accept on the AF_ALG socket");
+		goto out;
+	}
+
+	memset(null_msg, 0, sizeof(null_msg));
+
+	len = send(opfd, &null_msg, sizeof(null_msg), 0);
+	if (len != MAC_ZERO_LEN) {
+		rc = -errno;
+		pr_verbose(verbose, "Failed to send to the AF_ALG socket");
+		goto out;
+	}
+
+	len = read(opfd, mac_zero, sizeof(mac_zero));
+	if (len < SHA_256_HASH_SIZE) {
+		rc = -errno;
+		pr_verbose(verbose, "Failed to receive from the AF_ALG socket");
+		goto out;
+	}
+
+	memset(vp, 0, vp_len);
+	for (i = 0; i < SHA_256_HASH_SIZE; i++)
+		sprintf(&vp[i * 2], "%02x", mac_zero[i]);
+
+	pr_verbose(verbose, "Key verification pattern:  %s", vp);
+
+out:
+	if (opfd != -1)
+		close(opfd);
+	if (tfmfd != -1)
+		close(tfmfd);
+
+	if (rc != 0)
+		pr_verbose(verbose, "Failed to generate the key verification "
+			   "pattern: %s", strerror(-rc));
+
+	return rc;
+}
+
 /**
  * Generate a key verification pattern of a secure key by encrypting the all
  * zero message with the secure key using the AF_ALG interface
@@ -1638,8 +1766,17 @@ out:
 int generate_key_verification_pattern(const u8 *key, size_t key_size,
 				      char *vp, size_t vp_len, bool verbose)
 {
-	return generate_aes_key_verification_pattern(key, key_size, vp, vp_len,
-						     NULL, verbose);
+	if (is_aes_key(key, key_size))
+		return generate_aes_key_verification_pattern(key, key_size,
+							     vp, vp_len,
+							     NULL, verbose);
+	if (is_hmac_key(key, key_size))
+		return generate_hmac_key_verification_pattern(key, key_size,
+							      vp, vp_len,
+							      NULL, verbose);
+
+	pr_verbose(verbose, "Neither an AES nor an HMAC key");
+	return -EINVAL;
 }
 
 int get_master_key_verification_pattern(const u8 *key, size_t key_size,
@@ -1863,6 +2000,35 @@ bool is_pvsecret_aes_key(const u8 *key, size_t key_size)
 	}
 }
 
+/**
+ * Check if the specified key is a PVSECRET-HMAC key token.
+ *
+ * @param[in] key           the secure key token
+ * @param[in] key_size      the size of the secure key
+ *
+ * @returns true if the key is a PVSECRET token type
+ */
+bool is_pvsecret_hmac_key(const u8 *key, size_t key_size)
+{
+	struct pvsecrettoken *pvsecret = (struct pvsecrettoken *)key;
+
+	if (key == NULL || key_size < PVSECRET_KEY_SIZE)
+		return false;
+
+	if (pvsecret->hdr.type != TOKEN_TYPE_NON_CCA)
+		return false;
+	if (pvsecret->hdr.version != TOKEN_VERSION_PVSECRET)
+		return false;
+
+	switch (pvsecret->secret_type) {
+	case UV_SECRET_TYPE_HMAC_SHA_256:
+	case UV_SECRET_TYPE_HMAC_SHA_512:
+		return true;
+	default:
+		return false;
+	}
+}
+
 /**
  * Check if the specified key is an XTS type key
  *
@@ -1930,6 +2096,46 @@ bool is_secure_key(const u8 *key, size_t key_size)
 	return false;
 }
 
+/**
+ * Check if the specified key is an AES key type
+ *
+ * @param[in] key           the secure key token
+ * @param[in] key_size      the size of the secure key
+ *
+ * @returns true if the key is a secure key type
+ */
+bool is_aes_key(const u8 *key, size_t key_size)
+{
+	if (is_cca_aes_data_key(key, key_size))
+		return true;
+	if (is_cca_aes_cipher_key(key, key_size))
+		return true;
+	if (is_ep11_aes_key(key, key_size))
+		return true;
+	if (is_ep11_aes_key_with_header(key, key_size))
+		return true;
+	if (is_pvsecret_aes_key(key, key_size))
+		return true;
+
+	return false;
+}
+
+/**
+ * Check if the specified key is an HMAC key type
+ *
+ * @param[in] key           the secure key token
+ * @param[in] key_size      the size of the secure key
+ *
+ * @returns true if the key is a secure key type
+ */
+bool is_hmac_key(const u8 *key, size_t key_size)
+{
+	if (is_pvsecret_hmac_key(key, key_size))
+		return true;
+
+	return false;
+}
+
 /**
  * Gets the size in bits of the effective key of the specified secure key
  *
@@ -2002,6 +2208,17 @@ int get_key_bit_size(const u8 *key, size_t key_size, size_t *bitsize)
 		default:
 			return -EINVAL;
 		}
+	} else if (is_pvsecret_hmac_key(key, key_size)) {
+		switch (pvsecret->secret_type) {
+		case UV_SECRET_TYPE_HMAC_SHA_256:
+			*bitsize = 512;
+			break;
+		case UV_SECRET_TYPE_HMAC_SHA_512:
+			*bitsize = 1024;
+			break;
+		default:
+			return -EINVAL;
+		}
 	} else {
 		return -EINVAL;
 	}
@@ -2029,6 +2246,8 @@ const char *get_key_type(const u8 *key, size_t key_size)
 		return KEY_TYPE_EP11_AES;
 	if (is_pvsecret_aes_key(key, key_size))
 		return KEY_TYPE_PVSECRET_AES;
+	if (is_pvsecret_hmac_key(key, key_size))
+		return KEY_TYPE_PVSECRET_HMAC;
 
 	return NULL;
 }
@@ -2052,6 +2271,42 @@ bool is_secure_key_type(const char *key_type)
 	return false;
 }
 
+/**
+ * Returns true if the key type is an AES key type
+ *
+ * @param[in] key_type       the type of the key
+ *
+ * @returns true if the key type is an AES key type, false otherwise
+ */
+bool is_aes_key_type(const char *key_type)
+{
+	if (strcasecmp(key_type, KEY_TYPE_CCA_AESCIPHER) == 0)
+		return true;
+	if (strcasecmp(key_type, KEY_TYPE_CCA_AESDATA) == 0)
+		return true;
+	if (strcasecmp(key_type, KEY_TYPE_EP11_AES) == 0)
+		return true;
+	if (strcasecmp(key_type, KEY_TYPE_PVSECRET_AES) == 0)
+		return true;
+
+	return false;
+}
+
+/**
+ * Returns true if the key type is a HMAC key type
+ *
+ * @param[in] key_type       the type of the key
+ *
+ * @returns true if the key type is a HMAC key type, false otherwise
+ */
+bool is_hmac_key_type(const char *key_type)
+{
+	if (strcasecmp(key_type, KEY_TYPE_PVSECRET_HMAC) == 0)
+		return true;
+
+	return false;
+}
+
 /**
  * Returns the minimum card level for a specific key type
  *
