@@ -302,10 +302,14 @@ struct pkey_apqns4keytype {
 #define KEY_TYPE_CCA_AESCIPHER      "CCA-AESCIPHER"
 #define KEY_TYPE_EP11_AES           "EP11-AES"
 #define KEY_TYPE_PVSECRET_AES       "PVSECRET-AES"
+#define KEY_TYPE_PVSECRET_HMAC      "PVSECRET-HMAC"
 
 #define DEFAULT_KEYBITS             256
 #define PAES_BLOCK_SIZE             16
 #define ENC_ZERO_LEN                (2 * PAES_BLOCK_SIZE)
+#define SHA_256_HASH_SIZE           32
+#define SHA_512_HASH_SIZE           64
+#define MAC_ZERO_LEN                SHA_512_HASH_SIZE
 #define VERIFICATION_PATTERN_LEN    (2 * ENC_ZERO_LEN + 1)
 
 #define MKVP_LENGTH		16
@@ -330,12 +334,14 @@ int open_pkey_device(bool verbose);
 
 int generate_secure_key_random(int pkey_fd, const char *keyfile,
 			       size_t keybits, bool xts, const char *key_type,
-			       const char **apqns, bool verbose);
+			       const char **apqns, bool exportable,
+			       bool wrap_with_trusted, bool verbose);
 
 int generate_secure_key_clear(int pkey_fd, const char *keyfile,
 			      size_t keybits, bool xts,
 			      const char *clearkeyfile, const char *key_type,
-			      const char **apqns, bool verbose);
+			      const char **apqns, bool exportable,
+			      bool wrap_with_trusted, bool verbose);
 
 u8 *read_secure_key(const char *keyfile, size_t *secure_key_size,
 		    bool verbose);
@@ -356,6 +362,12 @@ int generate_aes_key_verification_pattern(const u8 *key, size_t key_size,
 					  const char *cipher,
 					  bool verbose);
 
+int generate_hmac_key_verification_pattern(const u8 *key,
+					   size_t key_size,
+					   char *vp, size_t vp_len,
+					   const char *cipher,
+					   bool verbose);
+
 int get_master_key_verification_pattern(const u8 *key, size_t key_size,
 					u8 *mkvp, bool verbose);
 
@@ -365,15 +377,20 @@ bool is_ep11_aes_key(const u8 *key, size_t key_size);
 bool is_ep11_aes_key_with_header(const u8 *key, size_t key_size);
 bool is_ep11_key_session_bound(const u8 *key, size_t key_size);
 bool is_pvsecret_aes_key(const u8 *key, size_t key_size);
+bool is_pvsecret_hmac_key(const u8 *key, size_t key_size);
 bool is_xts_key(const u8 *key, size_t key_size);
 bool is_secure_key(const u8 *key, size_t key_size);
+bool is_aes_key(const u8 *key, size_t key_size);
+bool is_hmac_key(const u8 *key, size_t key_size);
 int get_key_bit_size(const u8 *key, size_t key_size, size_t *bitsize);
 const char *get_key_type(const u8 *key, size_t key_size);
 bool is_secure_key_type(const char *key_type);
+bool is_aes_key_type(const char *key_type);
+bool is_hmac_key_type(const char *key_type);
 int get_min_card_level_for_keytype(const char *key_type);
 const struct fw_version *get_min_fw_version_for_keytype(const char *key_type);
 enum card_type get_card_type_for_keytype(const char *key_type);
-int check_aes_cipher_key(const u8 *key, size_t key_size);
+int check_aes_cipher_key(const u8 *key, size_t key_size, bool exportable);
 
 enum reencipher_method {
 	REENCIPHER_OLD_TO_CURRENT = 1,
